# Portals
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/portals#overview)
  * [Use the Portal Feature](https://help.sap.com/docs/leanix/ea/portals#use-the-portal-feature)
  * [Portal Permissions](https://help.sap.com/docs/leanix/ea/portals#portal-permissions)
  * [Configure a Portal](https://help.sap.com/docs/leanix/ea/portals#configure-a-portal)
  * [Basic](https://help.sap.com/docs/leanix/ea/portals#basic)
  * [Status](https://help.sap.com/docs/leanix/ea/portals#status)
  * [Search](https://help.sap.com/docs/leanix/ea/portals#search-1)
  * [Detailed View](https://help.sap.com/docs/leanix/ea/portals#detailed-view)


View all
Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.
